@@ -1,41 +1,45 @@
 /*============================================================================
-*
-*   WCSLIB 4.2 - an implementation of the FITS WCS standard.
-*   Copyright (C) 1995-2005, Mark Calabretta
-*
-*   WCSLIB is free software; you can redistribute it and/or modify it under
-*   the terms of the GNU General Public License as published by the Free
-*   Software Foundation; either version 2 of the License, or (at your option)
-*   any later version.
-*
-*   WCSLIB is distributed in the hope that it will be useful, but WITHOUT ANY
-*   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-*   FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
-*   details.
-*
-*   You should have received a copy of the GNU General Public License along
-*   with WCSLIB; if not, write to the Free Software Foundation, Inc.,
-*   59 Temple Place, Suite 330, Boston, MA  02111-1307, USA
-*
-*   Correspondence concerning WCSLIB may be directed to:
-*      Internet email: mcalabre@atnf.csiro.au
-*      Postal address: Dr. Mark Calabretta
-*                      Australia Telescope National Facility, CSIRO
-*                      PO Box 76
-*                      Epping NSW 1710
-*                      AUSTRALIA
-*
-*   Author: Mark Calabretta, Australia Telescope National Facility
-*   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: getwcstab.h,v 4.2 2005/09/21 13:21:57 cal103 Exp $
+
+    WCSLIB 4.3 - an implementation of the FITS WCS standard.
+    Copyright (C) 1995-2007, Mark Calabretta
+
+    This file is part of WCSLIB.
+
+    WCSLIB is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by the
+    Free Software Foundation, either version 3 of the License, or (at your
+    option) any later version.
+
+    WCSLIB is distributed in the hope that it will be useful, but WITHOUT ANY
+    WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+    FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+    more details.
+
+    You should have received a copy of the GNU Lesser General Public License
+    along with WCSLIB.  If not, see <http://www.gnu.org/licenses/>.
+
+    Correspondence concerning WCSLIB may be directed to:
+       Internet email: mcalabre@atnf.csiro.au
+       Postal address: Dr. Mark Calabretta
+                       Australia Telescope National Facility, CSIRO
+                       PO Box 76
+                       Epping NSW 1710
+                       AUSTRALIA
+
+    Author: Mark Calabretta, Australia Telescope National Facility
+    http://www.atnf.csiro.au/~mcalabre/index.html
+    $Id: getwcstab.h,v 4.3 2007/12/27 05:41:36 cal103 Exp $
 *=============================================================================
 *
-*   IMPORTANT
-*   ---------
-*   The interface of fits_read_wcstab() is experimental, getwcstab.{h,c} must
-*   be considered beta-release code in WCSLIB 4.2.  The code will eventually
-*   be incorporated into CFITSIO with the definitions in getwcstab.h moved
-*   into fitsio.h.
+*   NOTE
+*   ----
+*   This implementation of a FITS -TAB table reading routine,
+*   fits_read_wcstab(), is provided for CFITSIO programmers.  It has been
+*   incorporated into CFITSIO v3.006 with the definitions in this file,
+*   getwcstab.h, moved into fitsio.h.
+*
+*   It may be useful for programmers using an older version of CFITSIO than
+*   3.006, or as a programming template for non-CFITSIO programmers.
 *
 *
 *   FITS -TAB table reading routine; fits_read_wcstab()
@@ -43,9 +47,6 @@
 *   fits_read_wcstab() extracts arrays from a binary table required in
 *   constructing -TAB coordinates.
 *
-*   This implementation is provided for CFITSIO programmers, but others should
-*   find the code in getwcstab.c useful as a programming template.
-*
 *   Given:
 *      fptr     fitsfile *
 *                        Pointer to the file handle returned, for example, by
@@ -71,26 +72,29 @@
 *   Notes
 *   -----
 *    1) In order to maintain WCSLIB and CFITSIO as independent libraries it
-*       was not permissible for any CFITSIO library code to include WCSLIB
+*       is not permissible for any CFITSIO library code to include WCSLIB
 *       header files, or vice versa.  However, the CFITSIO function
-*       fits_read_wcstab() accepts an array of structs defined by wcs.h within
-*       WCSLIB.  The problem then was to define this struct within fitsio.h
+*       fits_read_wcstab() accepts an array of wtbarr structs defined in wcs.h
+*       within WCSLIB.
+*
+*       The problem therefore is to define the wtbarr struct within fitsio.h
 *       without including wcs.h, especially noting that wcs.h will often (but
 *       not always) be included together with fitsio.h in an applications
 *       program that uses fits_read_wcstab().
 *
-*       Of the various possibilities, the solution adopted was for WCSLIB to
-*       define "struct wtbarr" while fitsio.h defines "typedef wtbarr", a
-*       untagged struct with identical members.  This allows both wcs.h and
-*       fitsio.h to define a wtbarr data type without conflict by virtue of
-*       the fact that structure tags and typedef names share different
-*       namespaces in C.  Appendix A, Sect. 11.1 (p206) of the K&R ANSI
-*       edition states that:
+*       The solution adopted is for WCSLIB to define "struct wtbarr" while
+*       fitsio.h defines "typedef wtbarr" as an untagged struct with identical
+*       members.  This allows both wcs.h and fitsio.h to define a wtbarr data
+*       type without conflict by virtue of the fact that structure tags and
+*       typedef names share different name spaces in C; Appendix A,
+*       Sect. A11.1 (p227) of the K&R ANSI edition states that:
 *
-*          ... identifiers associated with ordinary variables on the one hand
-*          and those associated with structure and union members and tags on
-*          the other form two disjoint classes which do not conflict.  [...]
-*          typedef names are in the same class as ordinary identifiers. [...]
+*          Identifiers fall into several name spaces that do not interfere
+*          with one another; the same identifier may be used for different
+*          purposes, even in the same scope, if the uses are in different
+*          name spaces.  These classes are: objects, functions, typedef names,
+*          and enum constants; labels; tags of structures, unions, and
+*          enumerations; and members of each structure or union individually.
 *
 *       Therefore, declarations within WCSLIB look like
 *
@@ -100,10 +104,19 @@
 *
 *          wtbarr *w;
 *
-*       but as suggested by the commonality of the names, these are really the
+*       As suggested by the commonality of the names, these are really the
 *       same aggregate data type.  However, in passing a (struct wtbarr *) to
 *       fits_read_wcstab() a cast to (wtbarr *) is formally required.
 *
+*       When using WCSLIB and CFITSIO together in C++ the situation is
+*       complicated by the fact that typedefs and structs share the same
+*       name space; C++ Annotated Reference Manual, Sect. 7.1.3 (p105).  In
+*       that case the wtbarr struct in wcs.h is renamed by preprocessor macro
+*       substitution to wtbarr_s to distinguish it from the typedef defined in
+*       fitsio.h.  However, the scope of this macro substitution is limited to
+*       wcs.h itself and CFITSIO programmer code, whether in C++ or C, should
+*       always use the wtbarr typedef.
+*
 *
 *   wtbarr typedef
 *   --------------
@@ -177,7 +190,7 @@ typedef struct {
 int fits_read_wcstab(fitsfile *, int, wtbarr *, int *);
 
 #ifdef __cplusplus
-};
+}
 #endif
 
 #endif /* WCSLIB_GETWCSTAB */
