@@ -1,33 +1,34 @@
 /*============================================================================
-*
-*   WCSLIB 4.2 - an implementation of the FITS WCS convention.
-*   Copyright (C) 1995-2005, Mark Calabretta
-*
-*   WCSLIB is free software; you can redistribute it and/or modify it under
-*   the terms of the GNU General Public License as published by the Free
-*   Software Foundation; either version 2 of the License, or (at your option)
-*   any later version.
-*
-*   WCSLIB is distributed in the hope that it will be useful, but WITHOUT ANY
-*   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-*   FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
-*   details.
-*
-*   You should have received a copy of the GNU General Public License along
-*   with WCSLIB; if not, write to the Free Software Foundation, Inc.,
-*   59 Temple Place, Suite 330, Boston, MA  02111-1307, USA
-*
-*   Correspondence concerning WCSLIB may be directed to:
-*      Internet email: mcalabre@atnf.csiro.au
-*      Postal address: Dr. Mark Calabretta
-*                      Australia Telescope National Facility, CSIRO
-*                      PO Box 76
-*                      Epping NSW 1710
-*                      AUSTRALIA
-*
-*   Author: Mark Calabretta, Australia Telescope National Facility
-*   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: twcs.c,v 4.2 2005/09/22 02:15:15 cal103 Exp $
+
+    WCSLIB 4.3 - an implementation of the FITS WCS standard.
+    Copyright (C) 1995-2007, Mark Calabretta
+
+    This file is part of WCSLIB.
+
+    WCSLIB is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by the
+    Free Software Foundation, either version 3 of the License, or (at your
+    option) any later version.
+
+    WCSLIB is distributed in the hope that it will be useful, but WITHOUT ANY
+    WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+    FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+    more details.
+
+    You should have received a copy of the GNU Lesser General Public License
+    along with WCSLIB.  If not, see <http://www.gnu.org/licenses/>.
+
+    Correspondence concerning WCSLIB may be directed to:
+       Internet email: mcalabre@atnf.csiro.au
+       Postal address: Dr. Mark Calabretta
+                       Australia Telescope National Facility, CSIRO
+                       PO Box 76
+                       Epping NSW 1710
+                       AUSTRALIA
+
+    Author: Mark Calabretta, Australia Telescope National Facility
+    http://www.atnf.csiro.au/~mcalabre/index.html
+    $Id: twcs.c,v 4.3 2007/12/27 05:35:51 cal103 Exp $
 *=============================================================================
 *
 *   twcs tests wcss2p() and wcsp2s() for closure on an oblique 2-D slice
@@ -50,7 +51,7 @@ void parser(struct wcsprm *);
 const double tol = 1.0e-10;
 
 
-/* In real life these would be encoded as FITS header cards. */
+/* In real life these would be encoded as FITS header keyrecords. */
 const int NAXIS = 4;
 const double CRPIX[4] =  {  513.0,  0.0,  0.0,  0.0};
 const double PC[4][4] = {{    1.1,  0.0,  0.0,  0.0},
@@ -83,13 +84,6 @@ int main()
           world1[361][NELEM], world2[361][NELEM];
    struct wcsprm *wcs;
 
-   /* Uncomment the following two lines to raise SIGFPE on floating point
-    * exceptions for the Sun FORTRAN compiler.  This signal can be caught
-    * within 'dbx' by issuing the command "catch FPE".
-    */
-/* #include <floatingpoint.h> */
-/* ieee_handler("set", "common", SIGFPE_ABORT); */
-
 
    printf("Testing closure of WCSLIB world coordinate transformation "
           "routines (twcs.c)\n"
@@ -103,42 +97,42 @@ int main()
    }
 
    printf("\nSize of data types (bytes):\n");
-   printf("           char:%5d\n", sizeof(char));
-   printf("      short int:%5d\n", sizeof(short int));
-   printf("            int:%5d\n", sizeof(int));
-   printf("       long int:%5d\n", sizeof(long int));
-   printf("          float:%5d\n", sizeof(float));
-   printf("         double:%5d\n", sizeof(double));
-   printf("         char *:%5d\n", sizeof(char *));
-   printf("   char (*)[72]:%5d\n", sizeof(char (*)[72]));
-   printf("          int *:%5d\n", sizeof(int *));
-   printf("        float *:%5d\n", sizeof(float *));
-   printf("       double *:%5d\n", sizeof(double *));
-   printf("struct pvcard *:%5d\n", sizeof(struct pvcard *));
-   printf("struct pscard *:%5d\n", sizeof(struct pscard *));
+   printf("           char:%5zd\n", sizeof(char));
+   printf("      short int:%5zd\n", sizeof(short int));
+   printf("            int:%5zd\n", sizeof(int));
+   printf("       long int:%5zd\n", sizeof(long int));
+   printf("          float:%5zd\n", sizeof(float));
+   printf("         double:%5zd\n", sizeof(double));
+   printf("         char *:%5zd\n", sizeof(char *));
+   printf("   char (*)[72]:%5zd\n", sizeof(char (*)[72]));
+   printf("          int *:%5zd\n", sizeof(int *));
+   printf("        float *:%5zd\n", sizeof(float *));
+   printf("       double *:%5zd\n", sizeof(double *));
+   printf("struct pvcard *:%5zd\n", sizeof(struct pvcard *));
+   printf("struct pscard *:%5zd\n", sizeof(struct pscard *));
 
    printf("\nSize of structs (bytes/ints):\n");
 
    s = (sizeof(struct linprm) == sizeof(int)*LINLEN) ? ok : mismatch;
-   printf("         linprm:%5d /%4d%s\n", sizeof(struct linprm), LINLEN, s);
+   printf("         linprm:%5zd /%4zd%s\n", sizeof(struct linprm), LINLEN, s);
 
    s = (sizeof(struct celprm) == sizeof(int)*CELLEN) ? ok : mismatch;
-   printf("         celprm:%5d /%4d%s\n", sizeof(struct celprm), CELLEN, s);
+   printf("         celprm:%5zd /%4zd%s\n", sizeof(struct celprm), CELLEN, s);
 
    s = (sizeof(struct prjprm) == sizeof(int)*PRJLEN) ? ok : mismatch;
-   printf("         prjprm:%5d /%4d%s\n", sizeof(struct prjprm), PRJLEN, s);
+   printf("         prjprm:%5zd /%4zd%s\n", sizeof(struct prjprm), PRJLEN, s);
 
    s = (sizeof(struct spcprm) == sizeof(int)*SPCLEN) ? ok : mismatch;
-   printf("         spcprm:%5d /%4d%s\n", sizeof(struct spcprm), SPCLEN, s);
+   printf("         spcprm:%5zd /%4zd%s\n", sizeof(struct spcprm), SPCLEN, s);
 
    s = (sizeof(struct tabprm) == sizeof(int)*TABLEN) ? ok : mismatch;
-   printf("         tabprm:%5d /%4d%s\n", sizeof(struct tabprm), TABLEN, s);
+   printf("         tabprm:%5zd /%4zd%s\n", sizeof(struct tabprm), TABLEN, s);
 
    s = (sizeof(struct wcsprm) == sizeof(int)*WCSLEN) ? ok : mismatch;
-   printf("         wcsprm:%5d /%4d%s\n", sizeof(struct wcsprm), WCSLEN, s);
+   printf("         wcsprm:%5zd /%4zd%s\n", sizeof(struct wcsprm), WCSLEN, s);
 
 
-   /* Set the PVi_ma cards for the longitude axis.             */
+   /* Set the PVi_ma keyvalues for the longitude axis.         */
    /*----------------------------------------------------------*/
    /* For test purposes, these are set so that the fiducial    */
    /* native coordinates are at the native pole, i.e. so that  */
@@ -153,7 +147,7 @@ int main()
    PV[1].m = 2;			/* Parameter number 2.         */
    PV[1].value = 90.0;		/* Fiducial native latitude.   */
 
-   /* Set the PVi_m cards for the latitude axis.               */
+   /* Set the PVi_m keyvaluess for the latitude axis.          */
    PV[2].i = 2;			/* Latitude is on axis 2.      */
    PV[2].m = 1;			/* Parameter number 1.         */
    PV[2].value = -30.0;		/* PVi_1.                      */
@@ -194,20 +188,20 @@ int main()
          world1[k][wcs->lat] = lat1;
       }
 
-      if (status = wcss2p(wcs, 361, NELEM, world1[0], phi, theta, img[0],
-                          pixel1[0], stat)) {
+      if ((status = wcss2p(wcs, 361, NELEM, world1[0], phi, theta, img[0],
+                           pixel1[0], stat))) {
          printf("   wcss2p(1) ERROR %2d (lat1 = %f)\n", status, lat1);
          continue;
       }
 
-      if (status = wcsp2s(wcs, 361, NELEM, pixel1[0], img[0], phi, theta,
-                          world2[0], stat)) {
+      if ((status = wcsp2s(wcs, 361, NELEM, pixel1[0], img[0], phi, theta,
+                           world2[0], stat))) {
          printf("   wcsp2s ERROR %2d (lat1 = %f)\n", status, lat1);
          continue;
       }
 
-      if (status = wcss2p(wcs, 361, NELEM, world2[0], phi, theta, img[0],
-                          pixel2[0], stat)) {
+      if ((status = wcss2p(wcs, 361, NELEM, world2[0], phi, theta, img[0],
+                           pixel2[0], stat))) {
          printf("   wcss2p(2) ERROR %2d (lat1 = %f)\n", status, lat1);
          continue;
       }
@@ -255,10 +249,10 @@ struct wcsprm *wcs;
    double *pcij;
 
    /* In practice a parser would read the FITS header until it encountered  */
-   /* the NAXIS card which must occur near the start of the header before   */
-   /* any of the WCS keywords.  It would then use wcsini() to allocate      */
-   /* memory for arrays in the wcsprm struct and set default values.        */
-   /* In this simulation the header keyvalues are set as global variables.  */
+   /* the NAXIS keyword which must occur near the start, before any of the  */
+   /* WCS keywords.  It would then use wcsini() to allocate memory for      */
+   /* arrays in the wcsprm struct and set default values.  In this          */
+   /* simulation the header keyvalues are set as global variables.          */
    wcsini(1, NAXIS, wcs);
 
 
@@ -301,7 +295,7 @@ struct wcsprm *wcs;
    }
 
    /* Extract information from the FITS header. */
-   if (status = wcsset(wcs)) {
+   if ((status = wcsset(wcs))) {
       printf("wcsset ERROR%3d\n", status);
    }
 
